/* plugin.c
 *
 * hashkill - a hash cracking tool
 * Copyright (C) 2010 Milen Rangelov <gat3way@gat3way.eu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <string.h>
#include <ctype.h>
#include <unistd.h>
#include <stdio.h>
#include "plugin.h"


/* Public functions */
void register_add_username(void *(*add_username)(const char *username));
void register_add_hash(void *(*add_hash)(const char *hash, int len));
void register_add_salt(void *(*add_salt)(const char *salt));
void register_add_salt2(void *(*add_salt2)(const char *salt2));
void register_md5(void * (*md5)(const char *plaintext, char *hashmd5, int len));
void register_md5_hex(void * (*md5_hex)(const char *hash, char *hashhex));
void register_sha1(void * (*sha1)(const char *plaintext, char *hash, int len));
void register_sha1_hex(void * (*sha1_hex)(const char *hash, char *hashhex));
void register_sha256(void * (*sha256)(const char *plaintext, char *hash, int len));
void register_sha256_hex(void * (*sha256_hex)(const char *hash, char *hashhex));
void register_sha512(void * (*sha512)(const char *plaintext, char *hash, int len));
void register_sha512_hex(void * (*sha512_hex)(const char *hash, char *hashhex));
void register_fcrypt(void * (*hfcrypt)(const char *password, const char *salt, char *ret));
int fastcompare(const char* s1, const char* s2, int length);
char* strupr(char* ioString);
char* strlow(char* ioString);






void register_add_username(void *(*add_username)(const char *username))
{
    hash_add_username = add_username;
}

void register_add_hash(void *(*add_hash)(const char *hash, int len))
{
    hash_add_hash = add_hash;
}

void register_add_salt(void *(*add_salt)(const char *salt))
{
    hash_add_salt = add_salt;
}

void register_add_salt2(void *(*add_salt2)(const char *salt2))
{
    hash_add_salt2 = add_salt2;
}

void register_md5(void * (*md5)(const char *plaintext, char *hashmd5, int len))
{
    hash_md5 = md5;
}

void register_md5_hex(void * (*md5_hex)(const char *hash, char *hashhex))
{
    hash_md5_hex = md5_hex;
}

void register_sha1(void * (*sha1)(const char *plaintext, char *hash, int len))
{
    hash_sha1 = sha1;
}

void register_sha1_hex(void * (*sha1_hex)(const char *hash, char *hashhex))
{
    hash_sha1_hex = sha1_hex;
}

void register_sha256(void * (*sha256)(const char *plaintext, char *hash, int len))
{
    hash_sha256 = sha256;
}

void register_sha256_hex(void * (*sha256_hex)(const char *hash, char *hashhex))
{
    hash_sha256_hex = sha256_hex;
}


void register_sha512(void * (*sha512)(const char *plaintext, char *hash, int len))
{
    hash_sha512 = sha512;
}

void register_sha512_hex(void * (*sha512_hex)(const char *hash, char *hashhex))
{
    hash_sha512_hex = sha512_hex;
}

void register_fcrypt(void * (*hfcrypt)(const char *password, const char *salt, char *ret))
{
    hash_fcrypt = hfcrypt;
}



int fastcompare(const char* s1, const char* s2, int length)
{
    register int i;
    
    for(i=0; i < length; i++)
    {
        if(*(s1+i) != *(s2+i)) return 1;
    }
    return 0;
}


char* strupr(char* ioString)
{
    int i;
    int theLength = (int)strlen(ioString);

    for(i=0; i<theLength; ++i) {ioString[i] = toupper(ioString[i]);}
    return ioString;
}


char* strlow(char* ioString)
{
    int i;
    int theLength = (int)strlen(ioString);

    for(i=0; i<theLength; ++i) {ioString[i] = tolower(ioString[i]);}
    return ioString;
}


void hex2str(char *str, char *hex, int len)
{
    int cnt, cnt1;
    unsigned char val=0;
    unsigned char tmp1=0,tmp2=0;
    char *charset="0123456789abcdef";
    bzero(str, (len/2));

    for (cnt=0;cnt<(len/2);cnt++)
    {
	val = 0;
	for (cnt1=0;cnt1<16;cnt1++) if (charset[cnt1] == hex[cnt*2]) tmp1 = cnt1;
	for (cnt1=0;cnt1<16;cnt1++) if (charset[cnt1] == hex[cnt*2+1]) tmp2 = cnt1;
	val |= (tmp1 << 4);
	val |= tmp2;
	
	*(str+cnt) = val;
    }
}





